pub struct PassbandPilotTrackDump {
pub pilot_phase_rad: Vec<f32>,
pub pilot_evm_pre: Vec<f32>,
pub pilot_evm_post: Vec<f32>,
pub hest_mag_mean: Vec<f32>,
pub hest_mag_max: Vec<f32>,
}Expand description
Per-symbol pilot-tracking summary for one packet.
Fields
pilot_phase_rad: Vec<f32>Residual pilot phase estimate per data symbol, in radians.
pilot_evm_pre: Vec<f32>Pilot EVM before the final pilot cleanup.
pilot_evm_post: Vec<f32>Pilot EVM after the final pilot cleanup.
hest_mag_mean: Vec<f32>Mean magnitude of the current channel estimate per tracked symbol.
hest_mag_max: Vec<f32>Maximum magnitude of the current channel estimate per tracked symbol.